@@ -6,27 +6,27 @@ use strict;
 use warnings;
 use bytes;
 
-use IO::Compress::Base::Common  2.095 ();
+use IO::Compress::Base::Common  2.100 qw(:Parse);
 
-use IO::Uncompress::Adapter::Inflate  2.095 ();
+use IO::Uncompress::Adapter::Inflate  2.100 ();
 
 
-use IO::Uncompress::Base  2.095 ;
-use IO::Uncompress::Gunzip  2.095 ;
-use IO::Uncompress::Inflate  2.095 ;
-use IO::Uncompress::RawInflate  2.095 ;
-use IO::Uncompress::Unzip  2.095 ;
+use IO::Uncompress::Base  2.100 ;
+use IO::Uncompress::Gunzip  2.100 ;
+use IO::Uncompress::Inflate  2.100 ;
+use IO::Uncompress::RawInflate  2.100 ;
+use IO::Uncompress::Unzip  2.100 ;
 
 require Exporter ;
 
 our ($VERSION, @ISA, @EXPORT_OK, %EXPORT_TAGS, $AnyInflateError);
 
-$VERSION = '2.095';
+$VERSION = '2.100';
 $AnyInflateError = '';
 
 @ISA = qw(IO::Uncompress::Base Exporter);
 @EXPORT_OK = qw( $AnyInflateError anyinflate ) ;
-%EXPORT_TAGS = %IO::Uncompress::Base::DEFLATE_CONSTANTS ;
+%EXPORT_TAGS = %IO::Uncompress::Base::DEFLATE_CONSTANTS if keys %IO::Uncompress::Base::DEFLATE_CONSTANTS;
 push @{ $EXPORT_TAGS{all} }, @EXPORT_OK ;
 Exporter::export_ok_tags('all');
 
@@ -48,7 +48,6 @@ sub anyinflate
 
 sub getExtraParams
 {
-    use IO::Compress::Base::Common  2.095 qw(:Parse);
     return ( 'rawinflate' => [Parse_boolean,  0] ) ;
 }
 
@@ -75,9 +74,9 @@ sub mkUncomp
         if ! defined $obj;
 
     *$self->{Uncomp} = $obj;
-    
+
      my @possible = qw( Inflate Gunzip Unzip );
-     unshift @possible, 'RawInflate' 
+     unshift @possible, 'RawInflate'
         if 1 || $got->getValue('rawinflate');
 
      my $magic = $self->ckMagic( @possible );
@@ -113,7 +112,7 @@ sub ckMagic
 
         $self->pushBack(*$self->{HeaderPending})  ;
         *$self->{HeaderPending} = ''  ;
-    }    
+    }
 
     bless $self => $keep;
     return undef;
@@ -135,7 +134,7 @@ IO::Uncompress::AnyInflate - Uncompress zlib-based (zip, gzip) file/buffer
     my $status = anyinflate $input => $output [,OPTS]
         or die "anyinflate failed: $AnyInflateError\n";
 
-    my $z = new IO::Uncompress::AnyInflate $input [OPTS]
+    my $z = IO::Uncompress::AnyInflate->new( $input [OPTS] )
         or die "anyinflate failed: $AnyInflateError\n";
 
     $status = $z->read($buffer)
@@ -444,7 +443,7 @@ uncompressed data to a buffer, C<$buffer>.
     use IO::Uncompress::AnyInflate qw(anyinflate $AnyInflateError) ;
     use IO::File ;
 
-    my $input = new IO::File "<file1.txt.Compressed"
+    my $input = IO::File->new( "<file1.txt.Compressed" )
         or die "Cannot open 'file1.txt.Compressed': $!\n" ;
     my $buffer ;
     anyinflate $input => \$buffer
@@ -479,7 +478,7 @@ and if you want to compress each file one at a time, this will do the trick
 
 The format of the constructor for IO::Uncompress::AnyInflate is shown below
 
-    my $z = new IO::Uncompress::AnyInflate $input [OPTS]
+    my $z = IO::Uncompress::AnyInflate->new( $input [OPTS] )
         or die "IO::Uncompress::AnyInflate failed: $AnyInflateError\n";
 
 Returns an C<IO::Uncompress::AnyInflate> object on success and undef on failure.
@@ -999,8 +998,7 @@ See the Changes file.
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2005-2020 Paul Marquess. All rights reserved.
+Copyright (c) 2005-2021 Paul Marquess. All rights reserved.
 
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
-
