@@ -16,12 +16,24 @@ BEGIN {
     $extra = 1
         if eval { require Test::NoWarnings ;  import Test::NoWarnings; 1 };
 
-    plan tests => 989 + $extra ;
+    plan tests => 1007 + $extra ;
 
     use_ok('IO::Uncompress::AnyUncompress', qw(anyuncompress $AnyUncompressError)) ;
 
 }
 
+my $OriginalContent1 = <<EOM ;
+Lorem ipsum dolor sit amet, consectetuer adipiscing elit. Ut tempus odio id
+ dolor. Camelus perlus.  Larrius in lumen numen.  Dolor en quiquum filia
+ est.  Quintus cenum parat.
+EOM
+
+my $OriginalContent2 = <<EOM ;
+LOREM ipsum dolor sit amet, consectetuer adipiscing elit. Ut tempus odio id
+ dolor. Camelus perlus.  Larrius in lumen numen.  Dolor en quiquum filia
+ est.  Quintus cenum PARAT.
+EOM
+
 sub run
 {
 
@@ -61,16 +73,16 @@ sub run
 
         my $in ;
         eval { $a = $Func->($in, \$x) ;} ;
-        like $@, mkErr("^$TopType: input filename is undef or null string"), 
+        like $@, mkErr("^$TopType: input filename is undef or null string"),
             '  Input filename undef' ;
 
-        $in = '';    
+        $in = '';
         eval { $a = $Func->($in, \$x) ;} ;
-        like $@, mkErr("^$TopType: input filename is undef or null string"), 
+        like $@, mkErr("^$TopType: input filename is undef or null string"),
             '  Input filename empty' ;
 
         {
-            my $lex1 = new LexFile my $in ;
+            my $lex1 = LexFile->new( my $in );
             writeFile($in, "abc");
             my $out = $in ;
             eval { $a = $Func->($in, $out) ;} ;
@@ -80,7 +92,7 @@ sub run
 
         {
             my $dir ;
-            my $lex = new LexDir $dir ;
+            my $lex = LexDir->new( $dir );
             my $d = quotemeta $dir;
 
             $a = $Func->("$dir", \$x) ;
@@ -97,7 +109,7 @@ sub run
         eval { $a = $Func->(\$in, \$in) ;} ;
         like $@, mkErr("^$TopType: input and output buffer are identical"),
             '  Input and Output buffer are the same';
-            
+
         SKIP:
         {
             # Threaded 5.6.x seems to have a problem comparing filehandles.
@@ -106,12 +118,12 @@ sub run
             skip 'Cannot compare filehandles with threaded $]', 2
                 if $] >= 5.006  && $] < 5.007 && $Config{useithreads};
 
-            my $lex = new LexFile my $out_file ;
+            my $lex = LexFile->new( my $out_file );
             open OUT, ">$out_file" ;
             eval { $a = $Func->(\*OUT, \*OUT) ;} ;
             like $@, mkErr("^$TopType: input and output handle are identical"),
                 '  Input and Output handle are the same';
-                
+
             close OUT;
             is -s $out_file, 0, "  File zero length" ;
         }
@@ -125,12 +137,12 @@ sub run
             eval { $a = $Func->(\$x, $object) ;} ;
             like $@, mkErr("^$TopType: illegal output parameter"),
                 '  Bad Output Param';
-                
+
             # Buffer not a scalar reference
             eval { $a = $Func->(\$x, \%x) ;} ;
             like $@, mkErr("^$TopType: illegal output parameter"),
                 '  Bad Output Param';
-                
+
 
             eval { $a = $Func->(\%x, \$x) ;} ;
             like $@, mkErr("^$TopType: illegal input parameter"),
@@ -147,13 +159,13 @@ sub run
         $a = $Func->($filename, \$x) ;
         is $a, undef, "  $TopType returned undef";
         like $$Error, "/^input file '$filename' does not exist\$/", "  input File '$filename' does not exist";
-            
+
         $filename = '/tmp/abd/abc.def';
         ok ! -e $filename, "  output File '$filename' does not exist";
         $a = $Func->(\$x, $filename) ;
         is $a, undef, "  $TopType returned undef";
         like $$Error, ("/^(cannot open file '$filename'|input file '$filename' does not exist):/"), "  output File '$filename' does not exist";
-            
+
         eval { $a = $Func->(\$x, '<abc>') } ;
         like $$Error, "/Need input fileglob for outout fileglob/",
                 '  Output fileglob with no input fileglob';
@@ -187,7 +199,7 @@ sub run
 
                 skip '\\ returns mutable value in 5.19.3', 1
                     if $] >= 5.019003;
-                
+
                 eval { $a = $Func->(\$in, \$out, TrailingData => \"abc") ;} ;
                 like $@, mkErr("^$TopType: Parameter 'TrailingData' not writable"),
                     '  TrailingData output not writable';
@@ -286,9 +298,8 @@ sub run
             my $already = '';
             $already = 'abcde' if $append ;
 
-            for my $buffer ( undef, '', "abcde" )
+            for my $buffer ( undef, '', $OriginalContent1 )
             {
-
                 my $disp_content = defined $buffer ? $buffer : '<undef>' ;
 
                 my $keep = $buffer;
@@ -304,8 +315,8 @@ sub run
                     is $keep, $buffer, "  Input buffer not changed" ;
                     my $got = anyUncompress(\$output, $already);
                     $got = undef if ! defined $buffer && $got eq '' ;
+                    ok ! $$Error, "  no error [$$Error]" ;
                     is $got, $buffer, "  Uncompressed matches original";
-
                 }
 
                 {
@@ -324,7 +335,7 @@ sub run
                 {
                     title "$TopType - From Array Ref to Array Ref content '$disp_content' Append $append" ;
 
-                    my $lex = new LexFile my $in_file ;
+                    my $lex = LexFile->new( my $in_file );
                     writeFile($in_file, $buffer);
                     my @output = ('first') ;
                     my @input = ($in_file);
@@ -339,7 +350,7 @@ sub run
                 {
                     title "$TopType - From Buff to Filename content '$disp_content' Append $append" ;
 
-                    my $lex = new LexFile my $out_file ;
+                    my $lex = LexFile->new( my $out_file );
                     ok ! -e $out_file, "  Output file does not exist";
                     writeFile($out_file, $already);
 
@@ -354,11 +365,11 @@ sub run
                 {
                     title "$TopType - From Buff to Handle content '$disp_content' Append $append" ;
 
-                    my $lex = new LexFile my $out_file ;
+                    my $lex = LexFile->new( my $out_file );
 
                     ok ! -e $out_file, "  Output file does not exist";
                     writeFile($out_file, $already);
-                    my $of = new IO::File ">>$out_file" ;
+                    my $of = IO::File->new( ">>$out_file" );
                     ok $of, "  Created output filehandle" ;
 
                     ok &$Func(\$buffer, $of, AutoClose => 1, Append => $append), '  Compressed ok' ;
@@ -373,7 +384,7 @@ sub run
                 {
                     title "$TopType - From Filename to Filename content '$disp_content' Append $append" ;
 
-                    my $lex = new LexFile(my $in_file, my $out_file) ;
+                    my $lex = LexFile->new( my $in_file, my $out_file) ;
                     writeFile($in_file, $buffer);
 
                     ok ! -e $out_file, "  Output file does not exist";
@@ -391,12 +402,12 @@ sub run
                 {
                     title "$TopType - From Filename to Handle content '$disp_content' Append $append" ;
 
-                    my $lex = new LexFile(my $in_file, my $out_file) ;
+                    my $lex = LexFile->new( my $in_file, my $out_file) ;
                     writeFile($in_file, $buffer);
 
                     ok ! -e $out_file, "  Output file does not exist";
                     writeFile($out_file, $already);
-                    my $out = new IO::File ">>$out_file" ;
+                    my $out = IO::File->new( ">>$out_file" );
 
                     ok &$Func($in_file, $out, AutoClose => 1, Append => $append), '  Compressed ok' ;
 
@@ -410,7 +421,7 @@ sub run
                 {
                     title "$TopType - From Filename to Buffer content '$disp_content' Append $append" ;
 
-                    my $lex = new LexFile(my $in_file, my $out_file) ;
+                    my $lex = LexFile->new( my $in_file, my $out_file) ;
                     writeFile($in_file, $buffer);
 
                     my $out = $already;
@@ -422,18 +433,18 @@ sub run
                     is $got, $buffer, "  Uncompressed matches original";
 
                 }
-                
+
                 {
                     title "$TopType - From Handle to Filename content '$disp_content' Append $append" ;
 
-                    my $lex = new LexFile(my $in_file, my $out_file) ;
+                    my $lex = LexFile->new( my $in_file, my $out_file) ;
                     writeFile($in_file, $buffer);
-                    my $in = new IO::File "<$in_file" ;
+                    my $in = IO::File->new( "<$in_file" );
 
                     ok ! -e $out_file, "  Output file does not exist";
                     writeFile($out_file, $already);
 
-                    ok &$Func($in, $out_file, Append => $append), '  Compressed ok' 
+                    ok &$Func($in, $out_file, Append => $append), '  Compressed ok'
                         or diag "error is $$Error" ;
 
                     ok -e $out_file, "  Created output file";
@@ -446,13 +457,13 @@ sub run
                 {
                     title "$TopType - From Handle to Handle content '$disp_content' Append $append" ;
 
-                    my $lex = new LexFile(my $in_file, my $out_file) ;
+                    my $lex = LexFile->new( my $in_file, my $out_file) ;
                     writeFile($in_file, $buffer);
-                    my $in = new IO::File "<$in_file" ;
+                    my $in = IO::File->new( "<$in_file" );
 
                     ok ! -e $out_file, "  Output file does not exist";
                     writeFile($out_file, $already);
-                    my $out = new IO::File ">>$out_file" ;
+                    my $out = IO::File->new( ">>$out_file" );
 
                     ok &$Func($in, $out, AutoClose => 1, Append => $append), '  Compressed ok' ;
 
@@ -466,9 +477,9 @@ sub run
                 {
                     title "$TopType - From Handle to Buffer content '$disp_content' Append $append" ;
 
-                    my $lex = new LexFile(my $in_file, my $out_file) ;
+                    my $lex = LexFile->new( my $in_file, my $out_file) ;
                     writeFile($in_file, $buffer);
-                    my $in = new IO::File "<$in_file" ;
+                    my $in = IO::File->new( "<$in_file" );
 
                     my $out = $already ;
 
@@ -483,7 +494,7 @@ sub run
                 {
                     title "$TopType - From stdin (via '-') to Buffer content '$disp_content' Append $append" ;
 
-                    my $lex = new LexFile(my $in_file, my $out_file) ;
+                    my $lex = LexFile->new( my $in_file, my $out_file) ;
                     writeFile($in_file, $buffer);
 
                        open(SAVEIN, "<&STDIN");
@@ -492,7 +503,7 @@ sub run
 
                     my $out = $already;
 
-                    ok &$Func('-', \$out, Append => $append), '  Compressed ok' 
+                    ok &$Func('-', \$out, Append => $append), '  Compressed ok'
                         or diag $$Error ;
 
                        open(STDIN, "<&SAVEIN");
@@ -517,24 +528,24 @@ sub run
         my $FuncInverse = getTopFuncRef($TopTypeInverse);
         my $ErrorInverse = getErrorRef($TopTypeInverse);
 
-        my $lex = new LexFile(my $file1, my $file2) ;
+        my $lex = LexFile->new( my $file1, my $file2) ;
 
-        writeFile($file1, "data1");
-        writeFile($file2, "data2");
-        my $of = new IO::File "<$file1" ;
+        writeFile($file1, $OriginalContent1);
+        writeFile($file2, $OriginalContent2);
+        my $of = IO::File->new( "<$file1" );
         ok $of, "  Created output filehandle" ;
 
         #my @input = (   undef, "", $file2, \undef, \'', \"abcde", $of) ;
-        #my @expected = ("", "", $file2, "", "", "abcde", "data1");
-        #my @uexpected = ("", "", "data2", "", "", "abcde", "data1");
+        #my @expected = ("", "", $file2, "", "", "abcde", $OriginalContent1);
+        #my @uexpected = ("", "", $OriginalContent2, "", "", "abcde", $OriginalContent1);
         #my @input = (   $file2, \"abcde", $of) ;
-        #my @expected = ( $file2, "abcde", "data1");
-        #my @uexpected = ("data2", "abcde", "data1");
+        #my @expected = ( $file2, "abcde", $OriginalContent1);
+        #my @uexpected = ($OriginalContent2, "abcde", $OriginalContent1);
 
         my @input = (   $file1, $file2) ;
         #my @expected = ( $file1, $file2);
-        my @expected = ("data1", "data2");
-        my @uexpected = ("data1", "data2");
+        my @expected = ($OriginalContent1, $OriginalContent2);
+        my @uexpected = ($OriginalContent1, $OriginalContent2);
 
         my @keep = @input ;
 
@@ -563,7 +574,7 @@ sub run
                 $of->open("<$file1") ;
 
                 my $output  ;
-                ok &$Func(\@input, \$output, MultiStream => $ms, AutoClose => 0), '  Compressed ok' 
+                ok &$Func(\@input, \$output, MultiStream => $ms, AutoClose => 0), '  Compressed ok'
                     or diag $$Error;
 
                 my $got = anyUncompress([ \$output, MultiStream => $ms ]);
@@ -576,7 +587,7 @@ sub run
             {
                 title "$TopType - From Array Ref to Filename, MultiStream $ms" ;
 
-                my $lex = new LexFile( my $file3) ;
+                my $lex = LexFile->new(  my $file3) ;
 
                 # rewind the filehandle
                 $of->open("<$file1") ;
@@ -594,9 +605,9 @@ sub run
             {
                 title "$TopType - From Array Ref to Filehandle, MultiStream $ms" ;
 
-                my $lex = new LexFile(my $file3) ;
+                my $lex = LexFile->new( my $file3) ;
 
-                my $fh3 = new IO::File ">$file3";
+                my $fh3 = IO::File->new( ">$file3" );
 
                 # rewind the filehandle
                 $of->open("<$file1") ;
@@ -617,7 +628,7 @@ sub run
             {
                 title "Truncated file";
                 skip '', 7
-                    if $CompressClass =~ /lzop|lzf|lzma/i ;
+                    if $CompressClass =~ /lzop|lzf|lzma|zstd|lzip/i ;
 
                 my @in ;
                 push @in, "abcde" x 10;
@@ -643,6 +654,33 @@ sub run
         }
     }
 
+    foreach my $bit ($CompressClass)
+    {
+
+        my $Error = getErrorRef($bit);
+        my $Func = getTopFuncRef($bit);
+        my $TopType = getTopFuncName($bit);
+
+        my $TopTypeInverse = getInverse($bit);
+        my $FuncInverse = getTopFuncRef($TopTypeInverse);
+        my $ErrorInverse = getErrorRef($TopTypeInverse);
+
+        title 'Round trip binary data that happens to include \r\n' ;
+
+        my $lex = LexFile->new( my $file1, my $file2, my $file3) ;
+
+        my $original = join '', map { chr } 0x00 .. 0xff ;
+        $original .= "data1\r\ndata2\r\ndata3\r\n" ;
+
+        writeFile($file1, $original);
+        is readFile($file1), $original;
+
+        ok &$Func($file1 => $file2), '  Compressed ok' ;
+        ok &$FuncInverse($file2 => $file3), '  Uncompressed ok' ;
+        is readFile($file3), $original, "  round tripped ok";
+
+    }
+
     foreach my $bit ($UncompressClass,
                     #'IO::Uncompress::AnyUncompress',
                     )
@@ -654,16 +692,20 @@ sub run
         my $C_Func = getTopFuncRef($CompressClass);
 
 
-        
+
         my $data = "mary had a little lamb" ;
         my $keep = $data ;
         my $extra = "after the main event";
 
+        SKIP:
         foreach my $fb ( qw( filehandle buffer ) )
         {
             title "Trailingdata with $TopType, from $fb";
 
-            my $lex = new LexFile my $name ;
+            skip "zstd doesn't support trailing data", 9
+                if $CompressClass =~ /zstd/i ;
+
+            my $lex = LexFile->new( my $name );
             my $input ;
 
             my $compressed ;
@@ -678,7 +720,7 @@ sub run
             {
                 writeFile($name, $compressed);
 
-                $input = new IO::File "<$name" ;
+                $input = IO::File->new( "<$name" );
             }
 
             my $trailing;
@@ -693,7 +735,7 @@ sub run
             }
 
             is $trailing . $rest, $extra, "  Got trailing data";
-            
+
         }
     }
 
@@ -709,10 +751,10 @@ sub run
 #
 #        my @inFiles  = map { "in$_.tmp"  } 1..4;
 #        my @outFiles = map { "out$_.tmp" } 1..4;
-#        my $lex = new LexFile(@inFiles, @outFiles);
+#        my $lex = LexFile->new( @inFiles, @outFiles);
 #
 #        writeFile($_, "data $_") foreach @inFiles ;
-#        
+#
 #        {
 #            title "$TopType - Hash Ref: to filename" ;
 #
@@ -749,8 +791,8 @@ sub run
 #            my @buffer ;
 #            my %hash = ( $inFiles[0] => undef,
 #                         $inFiles[1] => undef,
-#                         $inFiles[2] => undef, 
-#                     );  
+#                         $inFiles[2] => undef,
+#                     );
 #
 #            ok &$Func( \%hash ), '  Compressed ok' ;
 #
@@ -803,10 +845,10 @@ sub run
 #
 #        my @inFiles  = map { "in$_.tmp"  } 1..4;
 #        my @outFiles = map { "out$_.tmp" } 1..4;
-#        my $lex = new LexFile(@inFiles, @outFiles);
+#        my $lex = LexFile->new( @inFiles, @outFiles);
 #
 #        writeFile($_, "data $_") foreach @inFiles ;
-#        
+#
 #
 #
 #    #    if (0)
@@ -846,7 +888,7 @@ sub run
 #    #        title "$TopType - From Array Ref to Filename" ;
 #    #
 #    #        my ($file3) = ("file3");
-#    #        my $lex = new LexFile($file3) ;
+#    #        my $lex = LexFile->new( $file3) ;
 #    #
 #    #        # rewind the filehandle
 #    #        $of->open("<$file1") ;
@@ -864,9 +906,9 @@ sub run
 #    #        title "$TopType - From Array Ref to Filehandle" ;
 #    #
 #    #        my ($file3) = ("file3");
-#    #        my $lex = new LexFile($file3) ;
+#    #        my $lex = LexFile->new( $file3) ;
 #    #
-#    #        my $fh3 = new IO::File ">$file3";
+#    #        my $fh3 = IO::File->new( ">$file3" );
 #    #
 #    #        # rewind the filehandle
 #    #        $of->open("<$file1") ;
@@ -894,7 +936,7 @@ sub run
 
             my $tmpDir1 ;
             my $tmpDir2 ;
-            my $lex = new LexDir($tmpDir1, $tmpDir2) ;
+            my $lex = LexDir->new($tmpDir1, $tmpDir2) ;
             my $d1 = quotemeta $tmpDir1 ;
             my $d2 = quotemeta $tmpDir2 ;
 
@@ -909,7 +951,7 @@ sub run
             {
                 title "$TopType - From FileGlob to FileGlob files [@$files]" ;
 
-                ok &$Func("<$tmpDir1/a*.tmp>" => "<$tmpDir2/a#1.tmp>"), '  Compressed ok' 
+                ok &$Func("<$tmpDir1/a*.tmp>" => "<$tmpDir2/a#1.tmp>"), '  Compressed ok'
                     or diag $$Error ;
 
                 my @copy = @expected;
@@ -925,7 +967,7 @@ sub run
                 title "$TopType - From FileGlob to Array files [@$files]" ;
 
                 my @buffer = ('first') ;
-                ok &$Func("<$tmpDir1/a*.tmp>" => \@buffer), '  Compressed ok' 
+                ok &$Func("<$tmpDir1/a*.tmp>" => \@buffer), '  Compressed ok'
                     or diag $$Error ;
 
                 is shift @buffer, 'first';
@@ -945,8 +987,8 @@ sub run
                     title "$TopType - From FileGlob to Buffer files [@$files], MS $ms" ;
 
                     my $buffer ;
-                    ok &$Func("<$tmpDir1/a*.tmp>" => \$buffer, 
-                               MultiStream => $ms), '  Compressed ok' 
+                    ok &$Func("<$tmpDir1/a*.tmp>" => \$buffer,
+                               MultiStream => $ms), '  Compressed ok'
                         or diag $$Error ;
 
                     #hexDump(\$buffer);
@@ -961,10 +1003,10 @@ sub run
                 {
                     title "$TopType - From FileGlob to Filename files [@$files], MS $ms" ;
 
-                    my $lex = new LexFile(my $filename) ;
-                    
+                    my $lex = LexFile->new( my $filename) ;
+
                     ok &$Func("<$tmpDir1/a*.tmp>" => $filename,
-                              MultiStream => $ms), '  Compressed ok' 
+                              MultiStream => $ms), '  Compressed ok'
                         or diag $$Error ;
 
                     #hexDump(\$buffer);
@@ -979,11 +1021,11 @@ sub run
                 {
                     title "$TopType - From FileGlob to Filehandle files [@$files], MS $ms" ;
 
-                    my $lex = new LexFile(my $filename) ;
-                    my $fh = new IO::File ">$filename";
-                    
-                    ok &$Func("<$tmpDir1/a*.tmp>" => $fh, 
-                              MultiStream => $ms, AutoClose => 1), '  Compressed ok' 
+                    my $lex = LexFile->new( my $filename) ;
+                    my $fh = IO::File->new( ">$filename" );
+
+                    ok &$Func("<$tmpDir1/a*.tmp>" => $fh,
+                              MultiStream => $ms, AutoClose => 1), '  Compressed ok'
                         or diag $$Error ;
 
                     #hexDump(\$buffer);
@@ -1007,8 +1049,8 @@ sub run
         my $Func = getTopFuncRef($bit);
         my $TopType = getTopFuncName($bit);
 
-        my $buffer = "abcde" ;
-        my $buffer2 = "ABCDE" ;
+        my $buffer = $OriginalContent1;
+        my $buffer2 = $OriginalContent2;
         my $keep_orig = $buffer;
 
         my $comp = compressBuffer($UncompressClass, $buffer) ;
@@ -1054,7 +1096,7 @@ sub run
             {
                 title "$TopType - From Buff to Filename, Append($append)" ;
 
-                my $lex = new LexFile(my $out_file) ;
+                my $lex = LexFile->new( my $out_file) ;
                 if ($append)
                   { writeFile($out_file, $incumbent) }
                 else
@@ -1072,15 +1114,15 @@ sub run
             {
                 title "$TopType - From Buff to Handle, Append($append)" ;
 
-                my $lex = new LexFile(my $out_file) ;
+                my $lex = LexFile->new( my $out_file) ;
                 my $of ;
                 if ($append) {
                     writeFile($out_file, $incumbent) ;
-                    $of = new IO::File "+< $out_file" ;
+                    $of = IO::File->new( "+< $out_file" );
                 }
                 else {
                     ok ! -e $out_file, "  Output file does not exist" ;
-                    $of = new IO::File "> $out_file" ;
+                    $of = IO::File->new( "> $out_file" );
                 }
                 isa_ok $of, 'IO::File', '  $of' ;
 
@@ -1096,7 +1138,7 @@ sub run
             {
                 title "$TopType - From Filename to Filename, Append($append)" ;
 
-                my $lex = new LexFile(my $in_file, my $out_file) ;
+                my $lex = LexFile->new( my $in_file, my $out_file) ;
                 if ($append)
                   { writeFile($out_file, $incumbent) }
                 else
@@ -1116,15 +1158,15 @@ sub run
             {
                 title "$TopType - From Filename to Handle, Append($append)" ;
 
-                my $lex = new LexFile(my $in_file, my $out_file) ;
+                my $lex = LexFile->new( my $in_file, my $out_file) ;
                 my $out ;
                 if ($append) {
                     writeFile($out_file, $incumbent) ;
-                    $out = new IO::File "+< $out_file" ;
+                    $out = IO::File->new( "+< $out_file" );
                 }
                 else {
                     ok ! -e $out_file, "  Output file does not exist" ;
-                    $out = new IO::File "> $out_file" ;
+                    $out = IO::File->new( "> $out_file" );
                 }
                 isa_ok $out, 'IO::File', '  $out' ;
 
@@ -1142,7 +1184,7 @@ sub run
             {
                 title "$TopType - From Filename to Buffer, Append($append)" ;
 
-                my $lex = new LexFile(my $in_file) ;
+                my $lex = LexFile->new( my $in_file) ;
                 writeFile($in_file, $comp);
 
                 my $output ;
@@ -1157,14 +1199,14 @@ sub run
             {
                 title "$TopType - From Handle to Filename, Append($append)" ;
 
-                my $lex = new LexFile(my $in_file, my $out_file) ;
+                my $lex = LexFile->new( my $in_file, my $out_file) ;
                 if ($append)
                   { writeFile($out_file, $incumbent) }
                 else
                   { ok ! -e $out_file, "  Output file does not exist" }
 
                 writeFile($in_file, $comp);
-                my $in = new IO::File "<$in_file" ;
+                my $in = IO::File->new( "<$in_file" );
 
                 ok &$Func($in, $out_file, Append => $append, @opts), '  Uncompressed ok' ;
 
@@ -1178,20 +1220,20 @@ sub run
             {
                 title "$TopType - From Handle to Handle, Append($append)" ;
 
-                my $lex = new LexFile(my $in_file, my $out_file) ;
+                my $lex = LexFile->new( my $in_file, my $out_file) ;
                 my $out ;
                 if ($append) {
                     writeFile($out_file, $incumbent) ;
-                    $out = new IO::File "+< $out_file" ;
+                    $out = IO::File->new( "+< $out_file" );
                 }
                 else {
                     ok ! -e $out_file, "  Output file does not exist" ;
-                    $out = new IO::File "> $out_file" ;
+                    $out = IO::File->new( "> $out_file" );
                 }
                 isa_ok $out, 'IO::File', '  $out' ;
 
                 writeFile($in_file, $comp);
-                my $in = new IO::File "<$in_file" ;
+                my $in = IO::File->new( "<$in_file" );
 
                 ok &$Func($in, $out, Append => $append, AutoClose => 1, @opts), '  Uncompressed ok' ;
 
@@ -1205,9 +1247,9 @@ sub run
             {
                 title "$TopType - From Filename to Buffer, Append($append)" ;
 
-                my $lex = new LexFile(my $in_file) ;
+                my $lex = LexFile->new( my $in_file) ;
                 writeFile($in_file, $comp);
-                my $in = new IO::File "<$in_file" ;
+                my $in = IO::File->new( "<$in_file" );
 
                 my $output ;
                 $output = $incumbent if $append ;
@@ -1221,7 +1263,7 @@ sub run
             {
                 title "$TopType - From stdin (via '-') to Buffer content, Append($append) " ;
 
-                my $lex = new LexFile(my $in_file) ;
+                my $lex = LexFile->new( my $in_file) ;
                 writeFile($in_file, $comp);
 
                    open(SAVEIN, "<&STDIN");
@@ -1231,7 +1273,7 @@ sub run
                 my $output ;
                 $output = $incumbent if $append ;
 
-                ok &$Func('-', \$output, Append => $append, @opts), '  Uncompressed ok' 
+                ok &$Func('-', \$output, Append => $append, @opts), '  Uncompressed ok'
                     or diag $$Error ;
 
                    open(STDIN, "<&SAVEIN");
@@ -1244,14 +1286,14 @@ sub run
         {
             title "$TopType - From Handle to Buffer, InputLength" ;
 
-            my $lex = new LexFile(my $in_file, my $out_file) ;
+            my $lex = LexFile->new( my $in_file, my $out_file) ;
             my $out ;
 
             my $expected = $buffer ;
             my $appended = 'appended';
             my $len_appended = length $appended;
             writeFile($in_file, $comp . $appended . $comp . $appended) ;
-            my $in = new IO::File "<$in_file" ;
+            my $in = IO::File->new( "<$in_file" );
 
             ok &$Func($in, \$out, Transparent => 0, InputLength => length $comp, @opts), '  Uncompressed ok' ;
 
@@ -1275,7 +1317,7 @@ sub run
         {
             title "$TopType - From stdin (via $stdin) to Buffer content, InputLength" ;
 
-            my $lex = new LexFile my $in_file ;
+            my $lex = LexFile->new( my $in_file );
             my $expected = $buffer ;
             my $appended = 'appended';
             my $len_appended = length $appended;
@@ -1287,7 +1329,7 @@ sub run
 
             my $output ;
 
-            ok &$Func($stdin, \$output, Transparent => 0, InputLength => length $comp, @opts), '  Uncompressed ok' 
+            ok &$Func($stdin, \$output, Transparent => 0, InputLength => length $comp, @opts), '  Uncompressed ok'
                 or diag $$Error ;
 
             my $buff ;
@@ -1324,18 +1366,18 @@ sub run
 
         my $incumbent = "incumbent data" ;
 
-        my $lex = new LexFile(my $file1, my $file2) ;
+        my $lex = LexFile->new( my $file1, my $file2) ;
 
-        writeFile($file1, compressBuffer($UncompressClass,"data1"));
-        writeFile($file2, compressBuffer($UncompressClass,"data2"));
+        writeFile($file1, compressBuffer($UncompressClass, $OriginalContent1));
+        writeFile($file2, compressBuffer($UncompressClass, $OriginalContent2));
 
-        my $of = new IO::File "<$file1" ;
+        my $of = IO::File->new( "<$file1" );
         ok $of, "  Created output filehandle" ;
 
         #my @input    = ($file2, \$undef, \$null, \$comp, $of) ;
         #my @expected = ('data2', '',      '',    'abcde', 'data1');
         my @input    = ($file1, $file2);
-        my @expected = ('data1', 'data2');
+        my @expected = ($OriginalContent1, $OriginalContent2);
 
         my @keep = @input ;
 
@@ -1351,7 +1393,7 @@ sub run
         {
             title "$TopType - From ArrayRef to Filename" ;
 
-            my $lex = new LexFile my $output;
+            my $lex = LexFile->new( my $output );
             $of->open("<$file1") ;
 
             ok &$Func(\@input, $output, AutoClose => 0, @opts), '  UnCompressed ok' ;
@@ -1362,8 +1404,8 @@ sub run
         {
             title "$TopType - From ArrayRef to Filehandle" ;
 
-            my $lex = new LexFile my $output;
-            my $fh = new IO::File ">$output" ;
+            my $lex = LexFile->new( my $output );
+            my $fh = IO::File->new( ">$output" );
             $of->open("<$file1") ;
 
             ok &$Func(\@input, $fh, AutoClose => 0, @opts), '  UnCompressed ok' ;
@@ -1380,8 +1422,8 @@ sub run
             ok &$Func(\@input, \@output, AutoClose => 0, @opts), '  UnCompressed ok' ;
 
             is_deeply \@input, \@keep, "  Input array not changed" ;
-            is_deeply [map { defined $$_ ? $$_ : "" } @output], 
-                      ['first', @expected], 
+            is_deeply [map { defined $$_ ? $$_ : "" } @output],
+                      ['first', @expected],
                       "  Got Expected uncompressed data";
 
         }
@@ -1399,7 +1441,7 @@ sub run
 
         my $tmpDir1 ;
         my $tmpDir2 ;
-        my $lex = new LexDir($tmpDir1, $tmpDir2) ;
+        my $lex = LexDir->new($tmpDir1, $tmpDir2) ;
         my $d1 = quotemeta $tmpDir1 ;
         my $d2 = quotemeta $tmpDir2 ;
 
@@ -1418,7 +1460,7 @@ sub run
         {
             title "$TopType - From FileGlob to FileGlob" ;
 
-            ok &$Func("<$tmpDir1/a*.tmp>" => "<$tmpDir2/a#1.tmp>", @opts), '  UnCompressed ok' 
+            ok &$Func("<$tmpDir1/a*.tmp>" => "<$tmpDir2/a#1.tmp>", @opts), '  UnCompressed ok'
                 or diag $$Error ;
 
             my @copy = @expected;
@@ -1434,7 +1476,7 @@ sub run
             title "$TopType - From FileGlob to Arrayref" ;
 
             my @output = (\'first');
-            ok &$Func("<$tmpDir1/a*.tmp>" => \@output, @opts), '  UnCompressed ok' 
+            ok &$Func("<$tmpDir1/a*.tmp>" => \@output, @opts), '  UnCompressed ok'
                 or diag $$Error ;
 
             my @copy = ('first', @expected);
@@ -1450,7 +1492,7 @@ sub run
             title "$TopType - From FileGlob to Buffer" ;
 
             my $output ;
-            ok &$Func("<$tmpDir1/a*.tmp>" => \$output, @opts), '  UnCompressed ok' 
+            ok &$Func("<$tmpDir1/a*.tmp>" => \$output, @opts), '  UnCompressed ok'
                 or diag $$Error ;
 
             is $output, join('', @expected), "  got expected uncompressed data";
@@ -1459,9 +1501,9 @@ sub run
         {
             title "$TopType - From FileGlob to Filename" ;
 
-            my $lex = new LexFile my $output ;
+            my $lex = LexFile->new( my $output );
             ok ! -e $output, "  $output does not exist" ;
-            ok &$Func("<$tmpDir1/a*.tmp>" => $output, @opts), '  UnCompressed ok' 
+            ok &$Func("<$tmpDir1/a*.tmp>" => $output, @opts), '  UnCompressed ok'
                 or diag $$Error ;
 
             ok -e $output, "  $output does exist" ;
@@ -1471,9 +1513,9 @@ sub run
         {
             title "$TopType - From FileGlob to Filehandle" ;
 
-            my $lex = new LexFile my $output ;
-            my $fh = new IO::File ">$output" ;
-            ok &$Func("<$tmpDir1/a*.tmp>" => $fh, AutoClose => 1, @opts), '  UnCompressed ok' 
+            my $lex = LexFile->new( my $output );
+            my $fh = IO::File->new( ">$output" );
+            ok &$Func("<$tmpDir1/a*.tmp>" => $fh, AutoClose => 1, @opts), '  UnCompressed ok'
                 or diag $$Error ;
 
             ok -e $output, "  $output does exist" ;
@@ -1492,7 +1534,7 @@ sub run
 
         title "More write tests" ;
 
-        my $lex = new LexFile(my $file1, my $file2, my $file3) ;
+        my $lex = LexFile->new( my $file1, my $file2, my $file3) ;
 
         writeFile($file1, "F1");
         writeFile($file2, "F2");
@@ -1509,9 +1551,9 @@ sub run
 #        {
 #            my ($send, $get) = @$data ;
 #
-#            my $fh1 = new IO::File "< $file1" ;
-#            my $fh2 = new IO::File "< $file2" ;
-#            my $fh3 = new IO::File "< $file3" ;
+#            my $fh1 = IO::File->new( "< $file1" );
+#            my $fh2 = IO::File->new( "< $file2" );
+#            my $fh3 = IO::File->new( "< $file3" );
 #
 #            title "$send";
 #            my ($copy);
@@ -1545,9 +1587,9 @@ sub run
         {
             my ($send, $get) = @$data ;
 
-            my $fh1 = new IO::File "< $file1" ;
-            my $fh2 = new IO::File "< $file2" ;
-            my $fh3 = new IO::File "< $file3" ;
+            my $fh1 = IO::File->new( "< $file1" );
+            my $fh2 = IO::File->new( "< $file2" );
+            my $fh3 = IO::File->new( "< $file3" );
 
             title "$send";
             my($copy);
@@ -1562,8 +1604,8 @@ sub run
         }
 
         @data = (
-                   '[""]', 
-                   '[undef]', 
+                   '[""]',
+                   '[undef]',
                 ) ;
 
 
@@ -1574,7 +1616,7 @@ sub run
             eval "\$copy = $send";
             my $Answer ;
             eval { &$Func($copy, \$Answer) } ;
-            like $@, mkErr("^$TopFuncName: input filename is undef or null string"), 
+            like $@, mkErr("^$TopFuncName: input filename is undef or null string"),
                 "  got error message";
 
         }
@@ -1582,11 +1624,11 @@ sub run
 
 
     {
-        # check setting $/ 
+        # check setting $\
 
         my $CompFunc = getTopFuncRef($CompressClass);
         my $UncompFunc = getTopFuncRef($UncompressClass);
-        my $lex = new LexFile my $file ;
+        my $lex = LexFile->new( my $file );
 
         local $\ = "\n" ;
         my $input = "hello world";
@@ -1599,7 +1641,32 @@ sub run
 
     }
 
+    SKIP:
+    {
+        #95494: IO::Uncompress::Gunzip: Can no longer gunzip to in-memory file handle
+
+        skip "open filehandle to buffer not supported in Perl $]", 7
+            if $] < 5.008 ;
+        my $CompFunc = getTopFuncRef($CompressClass);
+        my $UncompFunc = getTopFuncRef($UncompressClass);
+
+        my $input = "hello world";
+        my $compressed ;
+        ok open my $fh_in1, '<', \$input ;
+        ok open my $fh_out1, '>', \$compressed ;
+        ok &$CompFunc($fh_in1 => $fh_out1), '  Compressed ok' ;
+
+        my $output;
+        ok open my $fh_in2, '<', \$compressed ;
+        ok open my $fh_out2, '>', \$output ;
+
+        ok &$UncompFunc($fh_in2 => $fh_out2), '  UnCompressed ok' ;
+        is $output, $input, "round trip ok" ;
+    }
+
+
 }
+
 # TODO add more error cases
 
 1;
